aboutsummaryrefslogtreecommitdiff
path: root/bin
diff options
context:
space:
mode:
Diffstat (limited to 'bin')
-rw-r--r--bin/printer.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/bin/printer.py b/bin/printer.py
index 7fbe258..a733e25 100644
--- a/bin/printer.py
+++ b/bin/printer.py
@@ -320,9 +320,11 @@ class Printer:
output = textbox.edit(validator)
curses.curs_set(False)
# Finally, extract data from console and send to handler.
self.__sim.handler.handle_console(output)
self.screen.clear()
+ self.on_resize()
def show_console_error(self, message):
""" Shows Salis console error messages, if any. These messages might
@@ -354,6 +356,7 @@ class Printer:
textbox.edit(validator)
self.screen.clear()
+ self.on_resize()
def print_page(self):
""" Print current page to screen. We use the previously generated
@@ -320,9 +320,11 @@ class Printer:
output = textbox.edit(validator)
curses.curs_set(False)
- # Finally, extract data from console and send to handler.
+ # Finally, extract data from console and send to handler. Respond to
+ # any possible resize event here.
self.__sim.handler.handle_console(output)
self.screen.clear()